@@ -23,7 +23,16 @@
 #define GLMARK2_CANVAS_ANDROID_H_
 
 #include "canvas.h"
+#include "shared-library.h"
+#include "glad/egl.h"
 
+/**
+ * Canvas for rendering to Android surfaces.
+ *
+ * This class doesn't perform any GLES2.0 surface and context management
+ * (contrary to the CanvasX11* classes); these are handled in the Java
+ * Android code.
+ */
 class CanvasAndroid : public Canvas
 {
 public:
@@ -40,6 +49,13 @@ public:
     void write_to_file(std::string &filename);
     bool should_quit();
     void resize(int width, int height);
+
+private:
+    SharedLibrary egl_lib_;
+    SharedLibrary gles_lib_;
+
+    static GLADapiproc load_proc(void *userdata, const char *name);
+    void init_gl_extensions();
 };
 
 #endif
