@@ -18,6 +18,36 @@
 #include "vec.h"
 #include "util.h"
 
+namespace
+{
+
+bool is_valid_precision_value(ShaderSource::PrecisionValue precision_value)
+{
+    switch(precision_value) {
+        case ShaderSource::PrecisionValueLow:
+        case ShaderSource::PrecisionValueMedium:
+        case ShaderSource::PrecisionValueHigh:
+        case ShaderSource::PrecisionValueDefault:
+            return true;
+        default:
+            return false;
+    }
+}
+
+bool is_valid_shader_type(ShaderSource::ShaderType shader_type)
+{
+    switch(shader_type) {
+        case ShaderSource::ShaderTypeVertex:
+        case ShaderSource::ShaderTypeFragment:
+        case ShaderSource::ShaderTypeUnknown:
+            return true;
+        default:
+            return false;
+    }
+}
+
+}
+
 /**
  * Holds default precision values for all shader types
  * (even the unknown type, which is hardwired to default precision values)
@@ -34,7 +64,7 @@ ShaderSource::default_precision_(ShaderSource::ShaderTypeUnknown + 1);
 bool
 ShaderSource::load_file(const std::string& filename, std::string& str)
 {
-    std::auto_ptr<std::istream> is_ptr(Util::get_resource(filename));
+    std::unique_ptr<std::istream> is_ptr(Util::get_resource(filename));
     std::istream& inputFile(*is_ptr);
 
     if (!inputFile)
@@ -421,7 +451,9 @@ ShaderSource::emit_precision(std::stringstream& ss, ShaderSource::PrecisionValue
             ss << "#endif" << std::endl;
         }
     }
-    else if (val >= 0 && val < ShaderSource::PrecisionValueDefault) {
+    else if (is_valid_precision_value(val) &&
+             val != ShaderSource::PrecisionValueDefault)
+    {
         ss << "precision " << precision_map[val] << " ";
         ss << type_str << ";" << std::endl;
     }
@@ -512,7 +544,7 @@ void
 ShaderSource::default_precision(const ShaderSource::Precision& precision,
                                 ShaderSource::ShaderType type)
 {
-    if (type < 0 || type > ShaderSource::ShaderTypeUnknown)
+    if (!is_valid_shader_type(type))
         type = ShaderSource::ShaderTypeUnknown;
 
     if (type == ShaderSource::ShaderTypeUnknown) {
@@ -537,7 +569,7 @@ ShaderSource::default_precision(const ShaderSource::Precision& precision,
 const ShaderSource::Precision&
 ShaderSource::default_precision(ShaderSource::ShaderType type)
 {
-    if (type < 0 || type > ShaderSource::ShaderTypeUnknown)
+    if (!is_valid_shader_type(type))
         type = ShaderSource::ShaderTypeUnknown;
 
     return default_precision_[type];
@@ -589,7 +621,7 @@ ShaderSource::Precision::Precision(const std::string& precision_values) :
 {
     std::vector<std::string> elems;
 
-    Util::split(precision_values, ',', elems, Util::SplitModeNormal);
+    Util::split(precision_values, ',', elems, Util::SplitModeFuzzy);
 
     for (size_t i = 0; i < elems.size() && i < 4; i++) {
         const std::string& pstr(elems[i]);
