@@ -28,50 +28,38 @@
 #include "options.h"
 #include "log.h"
 #include "util.h"
-#include "text-renderer.h"
 #include "main-loop.h"
 #include "benchmark-collection.h"
+#include "scene-collection.h"
 
-#include <iostream>
-#include <fstream>
+#include "canvas-generic.h"
 
-#if USE_GL
-#include "canvas-x11-glx.h"
-#elif USE_GLESv2
-#include "canvas-x11-egl.h"
+#if GLMARK2_USE_X11
+#include "native-state-x11.h"
+#elif GLMARK2_USE_DRM
+#include "native-state-drm.h"
+#elif GLMARK2_USE_MIR
+#include "native-state-mir.h"
+#elif GLMARK2_USE_WAYLAND
+#include "native-state-wayland.h"
+#elif GLMARK2_USE_DISPMANX
+#include "native-state-dispmanx.h"
+#elif GLMARK2_USE_WIN32
+#include "native-state-win32.h"
+#endif
+
+#if GLMARK2_USE_EGL
+#include "gl-state-egl.h"
+#elif GLMARK2_USE_GLX
+#include "gl-state-glx.h"
+#elif GLMARK2_USE_WGL
+#include "gl-state-wgl.h"
 #endif
 
 using std::vector;
 using std::map;
 using std::string;
 
-void
-add_and_register_scenes(vector<Scene*>& scenes, Canvas& canvas)
-{
-    scenes.push_back(new SceneDefaultOptions(canvas));
-    scenes.push_back(new SceneBuild(canvas));
-    scenes.push_back(new SceneTexture(canvas));
-    scenes.push_back(new SceneShading(canvas));
-    scenes.push_back(new SceneConditionals(canvas));
-    scenes.push_back(new SceneFunction(canvas));
-    scenes.push_back(new SceneLoop(canvas));
-    scenes.push_back(new SceneBump(canvas));
-    scenes.push_back(new SceneEffect2D(canvas));
-    scenes.push_back(new ScenePulsar(canvas));
-    scenes.push_back(new SceneDesktop(canvas));
-    scenes.push_back(new SceneBuffer(canvas));
-    scenes.push_back(new SceneIdeas(canvas));
-    scenes.push_back(new SceneTerrain(canvas));
-    scenes.push_back(new SceneJellyfish(canvas));
-
-    for (vector<Scene*>::const_iterator iter = scenes.begin();
-         iter != scenes.end();
-         iter++)
-    {
-        Benchmark::register_scene(**iter);
-    }
-}
-
 static void
 list_scenes()
 {
@@ -156,7 +144,6 @@ do_validation(Canvas &canvas)
 int
 main(int argc, char *argv[])
 {
-
     if (!Options::parse_args(argc, argv))
         return 1;
 
@@ -178,20 +165,37 @@ main(int argc, char *argv[])
     }
 
     // Create the canvas
-#if USE_GL
-    CanvasX11GLX canvas(Options::size.first, Options::size.second);
-#elif USE_GLESv2
-    CanvasX11EGL canvas(Options::size.first, Options::size.second);
+#if GLMARK2_USE_X11
+    NativeStateX11 native_state;
+#elif GLMARK2_USE_DRM
+    NativeStateDRM native_state;
+#elif GLMARK2_USE_MIR
+    NativeStateMir native_state;
+#elif GLMARK2_USE_WAYLAND
+    NativeStateWayland native_state;
+#elif GLMARK2_USE_DISPMANX
+    NativeStateDispmanx native_state;
+#elif GLMARK2_USE_WIN32
+    NativeStateWin32 native_state;
 #endif
 
+#if GLMARK2_USE_EGL
+    GLStateEGL gl_state;
+#elif GLMARK2_USE_GLX
+    GLStateGLX gl_state;
+#elif GLMARK2_USE_WGL
+    GLStateWGL gl_state;
+#endif
+
+    CanvasGeneric canvas(native_state, gl_state, Options::size.first, Options::size.second);
+
     canvas.offscreen(Options::offscreen);
 
     canvas.visual_config(Options::visual_config);
 
-    vector<Scene*> scenes;
-
     // Register the scenes, so they can be looked up by name
-    add_and_register_scenes(scenes, canvas);
+    SceneCollection scenes(canvas);
+    scenes.register_scenes();
 
     if (Options::list_scenes) {
         list_scenes();
@@ -216,7 +220,5 @@ main(int argc, char *argv[])
     else
         do_benchmark(canvas);
 
-    Util::dispose_pointer_vector(scenes);
-
     return 0;
 }
