@@ -396,8 +396,9 @@ Mesh::update_single_array(const std::vector<std::pair<size_t, size_t> >& ranges,
         /* Update the current range from the vertex data */
         float *dest(array + nfloats * ri->first);
         for (size_t n = ri->first; n <= ri->second; n++) {
-            for (size_t i = 0; i < nfloats; i++)
-                *dest++ = vertices_[n][offset + i];
+            float *src(vertices_[n].data() + offset);
+            std::copy(src, src + nfloats, dest);
+            dest += nfloats;
         }
 
     }
@@ -543,6 +544,8 @@ void
 Mesh::render_array()
 {
     for (size_t i = 0; i < vertex_format_.size(); i++) {
+        if (attrib_locations_[i] < 0)
+            continue;
         glEnableVertexAttribArray(attrib_locations_[i]);
         glVertexAttribPointer(attrib_locations_[i], vertex_format_[i].first,
                               GL_FLOAT, GL_FALSE, vertex_stride_,
@@ -552,6 +555,8 @@ Mesh::render_array()
     glDrawArrays(GL_TRIANGLES, 0, vertices_.size());
 
     for (size_t i = 0; i < vertex_format_.size(); i++) {
+        if (attrib_locations_[i] < 0)
+            continue;
         glDisableVertexAttribArray(attrib_locations_[i]);
     }
 }
@@ -566,6 +571,8 @@ void
 Mesh::render_vbo()
 {
     for (size_t i = 0; i < vertex_format_.size(); i++) {
+        if (attrib_locations_[i] < 0)
+            continue;
         glEnableVertexAttribArray(attrib_locations_[i]);
         glBindBuffer(GL_ARRAY_BUFFER, vbos_[i]);
         glVertexAttribPointer(attrib_locations_[i], vertex_format_[i].first,
@@ -576,6 +583,8 @@ Mesh::render_vbo()
     glDrawArrays(GL_TRIANGLES, 0, vertices_.size());
 
     for (size_t i = 0; i < vertex_format_.size(); i++) {
+        if (attrib_locations_[i] < 0)
+            continue;
         glDisableVertexAttribArray(attrib_locations_[i]);
     }
 }
