@@ -24,6 +24,7 @@
  */
 #include "scene.h"
 #include "mat.h"
+#include "options.h"
 #include "stack.h"
 #include "vec.h"
 #include "log.h"
@@ -59,7 +60,7 @@ SceneShading::SceneShading(Canvas &pCanvas) :
     }
     options_["shading"] = Scene::Option("shading", "gouraud",
                                         "Which shading method to use",
-                                        "gouraud,blinn-phong-inf,phong");
+                                        "gouraud,blinn-phong-inf,phong,cel");
     options_["num-lights"] = Scene::Option("num-lights", "1",
             "The number of lights applied to the scene (phong only)");
     options_["model"] = Scene::Option("model", "cat", "Which model to use",
@@ -154,30 +155,36 @@ SceneShading::setup()
     ShaderSource vtx_source;
     ShaderSource frg_source;
     if (shading == "gouraud") {
-        vtx_shader_filename = GLMARK_DATA_PATH"/shaders/light-basic.vert";
-        frg_shader_filename = GLMARK_DATA_PATH"/shaders/light-basic.frag";
+        vtx_shader_filename = Options::data_path + "/shaders/light-basic.vert";
+        frg_shader_filename = Options::data_path + "/shaders/light-basic.frag";
         frg_source.append_file(frg_shader_filename);
         vtx_source.append_file(vtx_shader_filename);
         vtx_source.add_const("LightSourcePosition", lightPosition);
         vtx_source.add_const("MaterialDiffuse", materialDiffuse);
     }
     else if (shading == "blinn-phong-inf") {
-        vtx_shader_filename = GLMARK_DATA_PATH"/shaders/light-advanced.vert";
-        frg_shader_filename = GLMARK_DATA_PATH"/shaders/light-advanced.frag";
+        vtx_shader_filename = Options::data_path + "/shaders/light-advanced.vert";
+        frg_shader_filename = Options::data_path + "/shaders/light-advanced.frag";
         frg_source.append_file(frg_shader_filename);
         frg_source.add_const("LightSourcePosition", lightPosition);
         frg_source.add_const("LightSourceHalfVector", halfVector);
         vtx_source.append_file(vtx_shader_filename);
     }
     else if (shading == "phong") {
-        vtx_shader_filename = GLMARK_DATA_PATH"/shaders/light-phong.vert";
-        frg_shader_filename = GLMARK_DATA_PATH"/shaders/light-phong.frag";
+        vtx_shader_filename = Options::data_path + "/shaders/light-phong.vert";
+        frg_shader_filename = Options::data_path + "/shaders/light-phong.frag";
         unsigned int num_lights = Util::fromString<unsigned int>(options_["num-lights"].value);
         string fragsource = get_fragment_shader_source(frg_shader_filename, num_lights);
         frg_source.append(fragsource);
         frg_source.add_const("MaterialDiffuse", materialDiffuse);
         vtx_source.append_file(vtx_shader_filename);
     }
+    else if (shading == "cel") {
+        vtx_shader_filename = Options::data_path + "/shaders/light-phong.vert";
+        frg_shader_filename = Options::data_path + "/shaders/light-cel.frag";
+        vtx_source.append_file(vtx_shader_filename);
+        frg_source.append_file(frg_shader_filename);
+    }
 
     if (!Scene::load_shaders_from_strings(program_, vtx_source.str(),
                                           frg_source.str()))
@@ -220,7 +227,8 @@ SceneShading::setup()
         orientationVec_ = vec3(0.0, 1.0, 0.0);
     }
 
-    model.calculate_normals();
+    if (model.needNormals())
+        model.calculate_normals();
 
     /* Tell the converter that we only care about position and normal attributes */
     std::vector<std::pair<Model::AttribType, int> > attribs;
