@@ -234,6 +234,7 @@ protected:
     unsigned currentFrame_;
     bool running_;
     double duration_;      // Duration of run in seconds
+    unsigned nframes_;
 };
 
 /*
@@ -556,4 +557,50 @@ public:
     void draw();
     ValidationResult validate();
 };
+
+class ShadowPrivate;
+class SceneShadow : public Scene
+{
+    ShadowPrivate* priv_;
+public:
+    SceneShadow(Canvas& canvas);
+    bool supported(bool show_errors);
+    bool load();
+    void unload();
+    bool setup();
+    void teardown();
+    void update();
+    void draw();
+    ValidationResult validate();
+};
+
+class RefractPrivate;
+class SceneRefract : public Scene
+{
+    RefractPrivate* priv_;
+public:
+    SceneRefract(Canvas& canvas);
+    bool supported(bool show_errors);
+    bool load();
+    void unload();
+    bool setup();
+    void teardown();
+    void update();
+    void draw();
+    ValidationResult validate();
+};
+
+class SceneClear : public Scene
+{
+public:
+    SceneClear(Canvas &pCanvas);
+    bool load();
+    void unload();
+    bool setup();
+    void teardown();
+    void update();
+    void draw();
+    ValidationResult validate();
+};
+
 #endif
